@@ -26,7 +26,9 @@
 #' \item `"ml1"` calls [`dof_ml1()`].
 #' \item `"betwithin"` calls [`dof_betwithin()`].
 #' }
-#' For models with z-statistic, the returned degrees of freedom for model parameters is `Inf` (unless `method = "ml1"` or `method = "betwithin"`), because there is only one distribution for the related test statistic.
+#' For models with z-statistic, the returned degrees of freedom for model parameters
+#' is `Inf` (unless `method = "ml1"` or `method = "betwithin"`), because there is
+#' only one distribution for the related test statistic.
 #'
 #' @note
 #'
@@ -72,6 +74,9 @@ degrees_of_freedom <- function(model, ...) {
 #' @rdname degrees_of_freedom
 #' @export
 degrees_of_freedom.default <- function(model, method = "analytical", ...) {
+  # check for valid input
+  .is_model_valid(model)
+
   if (is.null(method)) {
     method <- "wald"
   }
@@ -264,7 +269,7 @@ dof <- degrees_of_freedom
       return(TRUE)
     } else {
       if (verbose) {
-        warning(insight::format_message(sprintf("'%s' must be one of 'wald', 'residual' or 'profile'. Using 'wald' now.", type)), call. = FALSE)
+        insight::format_warning(sprintf("`%s` must be one of \"wald\", \"residual\" or \"profile\". Using \"wald\" now.", type))
       }
       return(FALSE)
     }
@@ -273,7 +278,7 @@ dof <- degrees_of_freedom
   info <- insight::model_info(model, verbose = FALSE)
   if (!is.null(info) && isFALSE(info$is_mixed) && method == "boot") {
     if (verbose) {
-      warning(insight::format_message(sprintf("'%s=boot' only works for mixed models of class 'merMod'. To bootstrap this model, use `bootstrap=TRUE, ci_method=\"bcai\"`.", type)), call. = FALSE)
+      insight::format_warning(sprintf("`%s=boot` only works for mixed models of class `merMod`. To bootstrap this model, use `bootstrap=TRUE, ci_method=\"bcai\"`.", type))
     }
     return(TRUE)
   }
@@ -281,7 +286,7 @@ dof <- degrees_of_freedom
   if (is.null(info) || !info$is_mixed) {
     if (!(method %in% c("analytical", "any", "fit", "betwithin", "nokr", "wald", "ml1", "profile", "boot", "uniroot", "residual", "normal"))) {
       if (verbose) {
-        warning(insight::format_message(sprintf("'%s' must be one of 'residual', 'wald', normal', 'profile', 'boot', 'uniroot', 'betwithin' or 'ml1'. Using 'wald' now.", type)), call. = FALSE)
+        insight::format_warning(sprintf("`%s` must be one of \"residual\", \"wald\", \"normal\", \"profile\", \"boot\", \"uniroot\", \"betwithin\" or \"ml1\". Using \"wald\" now.", type))
       }
       return(FALSE)
     }
@@ -290,14 +295,14 @@ dof <- degrees_of_freedom
 
   if (!(method %in% c("analytical", "any", "fit", "satterthwaite", "betwithin", "kenward", "kr", "nokr", "wald", "ml1", "profile", "boot", "uniroot", "residual", "normal"))) {
     if (verbose) {
-      warning(insight::format_message(sprintf("'%s' must be one of 'residual', 'wald', 'normal', 'profile', 'boot', 'uniroot', 'kenward', 'satterthwaite', 'betwithin' or 'ml1'. Using 'wald' now.", type)), call. = FALSE)
+      insight::format_warning(sprintf("`%s` must be one of \"residual\", \"wald\", \"normal\", \"profile\", \"boot\", \"uniroot\", \"kenward\", \"satterthwaite\", \"betwithin\" or \"ml1\". Using \"wald\" now.", type))
     }
     return(FALSE)
   }
 
   if (!info$is_linear && method %in% c("satterthwaite", "kenward", "kr")) {
     if (verbose) {
-      warning(sprintf("'%s'-degrees of freedoms are only available for linear mixed models.", method), call. = FALSE)
+      insight::format_warning(sprintf("`%s`-degrees of freedoms are only available for linear mixed models.", method))
     }
     return(FALSE)
   }
