@@ -21,13 +21,14 @@ p_value.MCMCglmm <- function(model, ...) {
 }
 
 
+#' @rdname model_parameters.stanreg
 #' @export
 model_parameters.MCMCglmm <- function(model,
                                       centrality = "median",
                                       dispersion = FALSE,
-                                      ci = .95,
+                                      ci = 0.95,
                                       ci_method = "eti",
-                                      test = c("pd", "rope"),
+                                      test = "pd",
                                       rope_range = "default",
                                       rope_ci = 0.95,
                                       bf_prior = NULL,
@@ -35,10 +36,8 @@ model_parameters.MCMCglmm <- function(model,
                                       priors = TRUE,
                                       keep = NULL,
                                       drop = NULL,
-                                      parameters = keep,
                                       verbose = TRUE,
                                       ...) {
-
   # Processing
   params <-
     .extract_parameters_bayesian(
