@@ -4,9 +4,9 @@
 model_parameters.bamlss <- function(model,
                                     centrality = "median",
                                     dispersion = FALSE,
-                                    ci = .95,
+                                    ci = 0.95,
                                     ci_method = "eti",
-                                    test = c("pd", "rope"),
+                                    test = "pd",
                                     rope_range = "default",
                                     rope_ci = 0.95,
                                     component = "all",
@@ -14,7 +14,6 @@ model_parameters.bamlss <- function(model,
                                     standardize = NULL,
                                     keep = NULL,
                                     drop = NULL,
-                                    parameters = keep,
                                     verbose = TRUE,
                                     ...) {
   # Processing
