@@ -9,9 +9,7 @@ ci.mle2 <- ci.glm
 
 #' @export
 standard_error.mle2 <- function(model, ...) {
-  if (!requireNamespace("bbmle", quietly = TRUE)) {
-    stop("Package `bbmle` needs to be installed to extract standard errors.", call. = FALSE)
-  }
+  insight::check_if_installed("bbmle")
   s <- bbmle::summary(model)
   .data_frame(
     Parameter = names(s@coef[, 2]),
@@ -22,9 +20,7 @@ standard_error.mle2 <- function(model, ...) {
 
 #' @export
 p_value.mle2 <- function(model, ...) {
-  if (!requireNamespace("bbmle", quietly = TRUE)) {
-    stop("Package `bbmle` needs to be installed to extract p-values.", call. = FALSE)
-  }
+  insight::check_if_installed("bbmle")
   s <- bbmle::summary(model)
   .data_frame(
     Parameter = names(s@coef[, 4]),
