@@ -3,7 +3,9 @@
 model_parameters.deltaMethod <- function(model, p_adjust = NULL, verbose = TRUE, ...) {
   dots <- list(...)
   if ("ci" %in% names(dots)) {
-    warning(insight::format_message("The `ci` argument is not supported by `model_parameters` for objects of this class. Use the `level` argument of the `deltaMethod` function instead."), call. = FALSE)
+    warning(insight::format_message(
+      "The `ci` argument is not supported by `model_parameters` for objects of this class. Use the `level` argument of the `deltaMethod` function instead."
+    ), call. = FALSE)
     dots[["ci"]] <- NULL
   }
 
