@@ -1,12 +1,9 @@
 
+#' @rdname model_parameters.default
 #' @export
 model_parameters.censReg <- model_parameters.default
 
 
-#' @export
-ci.censReg <- ci.tobit
-
-
 #' @export
 standard_error.censReg <- standard_error.default
 
