@@ -10,7 +10,7 @@ model_parameters.gam <- model_parameters.cgam
 
 
 #' @export
-ci.gam <- function(x, ci = .95, method = NULL, ...) {
+ci.gam <- function(x, ci = 0.95, method = NULL, ...) {
   .ci_generic(model = x, ci = ci, method = "wald", ...)
 }
 
@@ -56,7 +56,7 @@ simulate_model.gam <- function(model, iterations = 1000, ...) {
   if (is.null(iterations)) iterations <- 1000
 
   beta <- stats::coef(model)
-  varcov <- insight::get_varcov(model, component = "all")
+  varcov <- insight::get_varcov(model, component = "all", ...)
 
   out <- as.data.frame(.mvrnorm(n = iterations, mu = beta, Sigma = varcov))
 
@@ -72,8 +72,7 @@ simulate_model.gam <- function(model, iterations = 1000, ...) {
 
 
 #' @export
-model_parameters.list <- function(model,
-                                  ...) {
+model_parameters.list <- function(model, ...) {
   if ("gam" %in% names(model)) {
     model <- model$gam
     class(model) <- c("gam", "lm", "glm")
@@ -82,13 +81,13 @@ model_parameters.list <- function(model,
     model <- model$pamobject
     model_parameters(model, ...)
   } else {
-    stop("We don't recognize this object of class 'list'. Please raise an issue.")
+    insight::format_error("We don't recognize this object of class `list`. Please raise an issue.")
   }
 }
 
 
 #' @export
-ci.list <- function(x, ci = .95, ...) {
+ci.list <- function(x, ci = 0.95, ...) {
   if ("gam" %in% names(x)) {
     x <- x$gam
     class(x) <- c("gam", "lm", "glm")
