@@ -8,7 +8,7 @@
 #' @rdname model_parameters.merMod
 #' @export
 model_parameters.glmmTMB <- function(model,
-                                     ci = .95,
+                                     ci = 0.95,
                                      ci_method = "wald",
                                      ci_random = NULL,
                                      bootstrap = FALSE,
@@ -23,7 +23,6 @@ model_parameters.glmmTMB <- function(model,
                                      summary = getOption("parameters_mixed_summary", FALSE),
                                      keep = NULL,
                                      drop = NULL,
-                                     parameters = keep,
                                      verbose = TRUE,
                                      df_method = ci_method,
                                      include_sigma = FALSE,
@@ -32,7 +31,9 @@ model_parameters.glmmTMB <- function(model,
 
   ## TODO remove later
   if (!missing(df_method) && !identical(ci_method, df_method)) {
-    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
+    warning(insight::format_message(
+      "Argument 'df_method' is deprecated. Please use 'ci_method' instead."
+    ), call. = FALSE)
     ci_method <- df_method
   }
 
@@ -54,7 +55,9 @@ model_parameters.glmmTMB <- function(model,
   # standardize only works for fixed effects...
   if (!is.null(standardize) && standardize != "refit") {
     if (!missing(effects) && effects != "fixed" && verbose) {
-      warning(insight::format_message("Standardizing coefficients only works for fixed effects of the mixed model."), call. = FALSE)
+      warning(insight::format_message(
+        "Standardizing coefficients only works for fixed effects of the mixed model."
+      ), call. = FALSE)
     }
     effects <- "fixed"
   }
@@ -83,7 +86,9 @@ model_parameters.glmmTMB <- function(model,
       if (effects != "fixed") {
         effects <- "fixed"
         if (verbose) {
-          warning(insight::format_message("Bootstrapping only returns fixed effects of the mixed model."), call. = FALSE)
+          warning(insight::format_message(
+            "Bootstrapping only returns fixed effects of the mixed model."
+          ), call. = FALSE)
         }
       }
     } else {
@@ -162,10 +167,20 @@ model_parameters.glmmTMB <- function(model,
     if (isTRUE(group_level)) {
       params_random <- .extract_random_parameters(model, ci = ci, effects = effects, component = component)
       if (length(random_effects) > 1) {
-        warning(insight::format_message("Cannot extract confidence intervals for random variance parameters from models with more than one grouping factor."), call. = FALSE)
+        insight::format_warning(
+          "Cannot extract confidence intervals for random variance parameters from models with more than one grouping factor."
+        )
       }
     } else {
-      params_variance <- .extract_random_variances(model, ci = ci, effects = effects, component = component, ci_method = ci_method, ci_random = ci_random, verbose = verbose)
+      params_variance <- .extract_random_variances(
+        model,
+        ci = ci,
+        effects = effects,
+        component = component,
+        ci_method = ci_method,
+        ci_random = ci_random,
+        verbose = verbose
+      )
       # remove redundant dispersion parameter
       if (isTRUE(dispersion_param) && !is.null(params) && !is.null(params$Component)) {
         disp <- which(params$Component == "dispersion")
@@ -190,7 +205,11 @@ model_parameters.glmmTMB <- function(model,
     params$Group <- ""
     # add component column
     if (!"Component" %in% colnames(params)) {
-      params$Component <- ifelse(component %in% c("zi", "zero_inflated"), "zero_inflated", "conditional")
+      if (component %in% c("zi", "zero_inflated")) {
+        params$Component <- "zero_inflated"
+      } else {
+        params$Component <- "conditional"
+      }
     }
 
     # reorder
@@ -246,7 +265,7 @@ model_parameters.glmmTMB <- function(model,
 #' @rdname ci.default
 #' @export
 ci.glmmTMB <- function(x,
-                       ci = .95,
+                       ci = 0.95,
                        dof = NULL,
                        method = "wald",
                        component = "all",
@@ -359,7 +378,11 @@ standard_error.glmmTMB <- function(model,
 
 #' @rdname simulate_model
 #' @export
-simulate_model.glmmTMB <- function(model, iterations = 1000, component = c("all", "conditional", "zi", "zero_inflated", "dispersion"), verbose = FALSE, ...) {
+simulate_model.glmmTMB <- function(model,
+                                   iterations = 1000,
+                                   component = c("all", "conditional", "zi", "zero_inflated", "dispersion"),
+                                   verbose = FALSE,
+                                   ...) {
   component <- match.arg(component)
   info <- insight::model_info(model, verbose = FALSE)
 
@@ -376,47 +399,62 @@ simulate_model.glmmTMB <- function(model, iterations = 1000, component = c("all"
 
   if (component == "all") {
     if (!has_zeroinflated && !has_dispersion) {
-      if (verbose) insight::print_color("No zero-inflation and dispersion components. Simulating from conditional parameters.\n", "red")
+      if (verbose) {
+        insight::print_color(
+          "No zero-inflation and dispersion components. Simulating from conditional parameters.\n",
+          "red"
+        )
+      }
       component <- "conditional"
     } else if (!has_zeroinflated && has_dispersion) {
-      if (verbose) insight::print_color("No zero-inflation component. Simulating from conditional and dispersion parameters.\n", "red")
+      if (verbose) {
+        insight::print_color(
+          "No zero-inflation component. Simulating from conditional and dispersion parameters.\n",
+          "red"
+        )
+      }
       component <- c("conditional", "dispersion")
     } else if (has_zeroinflated && !has_dispersion) {
-      if (verbose) insight::print_color("No dispersion component. Simulating from conditional and zero-inflation parameters.\n", "red")
+      if (verbose) {
+        insight::print_color(
+          "No dispersion component. Simulating from conditional and zero-inflation parameters.\n",
+          "red"
+        )
+      }
       component <- c("conditional", "zero_inflated")
     }
   } else if (component %in% c("zi", "zero_inflated") && !has_zeroinflated) {
-    stop("No zero-inflation model found.")
+    insight::format_error("No zero-inflation model found.")
   } else if (component == "dispersion" && !has_dispersion) {
-    stop("No dispersion model found.")
+    insight::format_error("No dispersion model found.")
   }
 
 
   if (is.null(iterations)) iterations <- 1000
 
   if (all(component == c("conditional", "zero_inflated"))) {
-    d1 <- .simulate_model(model, iterations, component = "conditional")
-    d2 <- .simulate_model(model, iterations, component = "zero_inflated")
+    d1 <- .simulate_model(model, iterations, component = "conditional", ...)
+    d2 <- .simulate_model(model, iterations, component = "zero_inflated", ...)
     colnames(d2) <- paste0(colnames(d2), "_zi")
     d <- cbind(d1, d2)
   } else if (all(component == c("conditional", "dispersion"))) {
-    d1 <- .simulate_model(model, iterations, component = "conditional")
-    d2 <- .simulate_model(model, iterations, component = "dispersion")
+    d1 <- .simulate_model(model, iterations, component = "conditional", ...)
+    d2 <- .simulate_model(model, iterations, component = "dispersion", ...)
     colnames(d2) <- paste0(colnames(d2), "_disp")
     d <- cbind(d1, d2)
   } else if (all(component == "all")) {
-    d1 <- .simulate_model(model, iterations, component = "conditional")
-    d2 <- .simulate_model(model, iterations, component = "zero_inflated")
-    d3 <- .simulate_model(model, iterations, component = "dispersion")
+    d1 <- .simulate_model(model, iterations, component = "conditional", ...)
+    d2 <- .simulate_model(model, iterations, component = "zero_inflated", ...)
+    d3 <- .simulate_model(model, iterations, component = "dispersion", ...)
     colnames(d2) <- paste0(colnames(d2), "_zi")
     colnames(d3) <- paste0(colnames(d3), "_disp")
     d <- cbind(d1, d2, d3)
   } else if (all(component == "conditional")) {
-    d <- .simulate_model(model, iterations, component = "conditional")
+    d <- .simulate_model(model, iterations, component = "conditional", ...)
   } else if (all(component %in% c("zi", "zero_inflated"))) {
-    d <- .simulate_model(model, iterations, component = "zero_inflated")
+    d <- .simulate_model(model, iterations, component = "zero_inflated", ...)
   } else {
-    d <- .simulate_model(model, iterations, component = "dispersion")
+    d <- .simulate_model(model, iterations, component = "dispersion", ...)
   }
 
   class(d) <- c("parameters_simulate_model", class(d))
@@ -435,7 +473,7 @@ simulate_model.glmmTMB <- function(model, iterations = 1000, component = c("all"
 simulate_parameters.glmmTMB <- function(model,
                                         iterations = 1000,
                                         centrality = "median",
-                                        ci = .95,
+                                        ci = 0.95,
                                         ci_method = "quantile",
                                         test = "p-value",
                                         ...) {
