@@ -48,7 +48,7 @@
 #' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.rma <- function(model,
-                                 ci = .95,
+                                 ci = 0.95,
                                  bootstrap = FALSE,
                                  iterations = 1000,
                                  standardize = NULL,
@@ -141,7 +141,7 @@ model_parameters.rma <- function(model,
   }
 
   original_attributes$names <- names(out)
-  original_attributes$row.names <- 1:nrow(out)
+  original_attributes$row.names <- seq_len(nrow(out))
   original_attributes$pretty_names <- stats::setNames(out$Parameter, out$Parameter)
   attributes(out) <- original_attributes
 
@@ -171,7 +171,7 @@ p_value.rma <- function(model, ...) {
 
 
 #' @export
-ci.rma <- function(x, ci = .95, ...) {
+ci.rma <- function(x, ci = 0.95, ...) {
   params <- insight::get_parameters(x)
   out <- tryCatch(
     {
