@@ -36,7 +36,7 @@
 #' @inheritParams simulate_model
 #' @export
 model_parameters.mlm <- function(model,
-                                 ci = .95,
+                                 ci = 0.95,
                                  vcov = NULL,
                                  vcov_args = NULL,
                                  bootstrap = FALSE,
@@ -69,7 +69,6 @@ standard_error.mlm <- function(model,
                                vcov = NULL,
                                vcov_args = NULL,
                                ...) {
-
   se <- standard_error.default(model, vcov = vcov, vcov_args = vcov_args, ...)
   est <- insight::get_parameters(model, ...)
   # assumes se and est are sorted the same way
@@ -78,11 +77,12 @@ standard_error.mlm <- function(model,
     se$Response <- est$Response
     return(se)
 
-  # manually
+    # manually
   } else {
     if (!is.null(vcov)) {
       warning(insight::format_message(
-        "Unable to extract the variance-covariance matrix requested in `vcov`."))
+        "Unable to extract the variance-covariance matrix requested in `vcov`."
+      ))
     }
     cs <- stats::coef(summary(model))
     se <- lapply(names(cs), function(x) {
@@ -91,7 +91,8 @@ standard_error.mlm <- function(model,
         Parameter = rownames(params),
         SE = params[, "Std. Error"],
         Response = gsub("^Response (.*)", "\\1", x)
-      )})
+      )
+    })
     se <- insight::text_remove_backticks(do.call(rbind, se), verbose = FALSE)
     return(se)
   }
@@ -100,7 +101,6 @@ standard_error.mlm <- function(model,
 
 #' @export
 p_value.mlm <- function(model, vcov = NULL, vcov_args = NULL, ...) {
-
   out <- p_value.default(model, vcov = vcov, vcov_args = vcov_args, ...)
   est <- insight::get_parameters(model, ...)
   # assumes out and est are sorted the same way
@@ -108,11 +108,12 @@ p_value.mlm <- function(model, vcov = NULL, vcov_args = NULL, ...) {
     out$Parameter <- est$Parameter
     out$Response <- est$Response
 
-  # manually
+    # manually
   } else {
     if (!is.null(vcov)) {
       warning(insight::format_message(
-        "Unable to extract the variance-covariance matrix requested in `vcov`."))
+        "Unable to extract the variance-covariance matrix requested in `vcov`."
+      ))
     }
     cs <- stats::coef(summary(model))
     p <- lapply(names(cs), function(x) {
@@ -134,8 +135,7 @@ p_value.mlm <- function(model, vcov = NULL, vcov_args = NULL, ...) {
 ci.mlm <- function(x,
                    vcov = NULL,
                    vcov_args = NULL,
-                   ci = .95, ...) {
-
+                   ci = 0.95, ...) {
   # .ci_generic may not handle weights properly (not sure)
   if (is.null(insight::find_weights(x)) && is.null(vcov)) {
     out <- lapply(ci, function(i) {
@@ -151,24 +151,25 @@ ci.mlm <- function(x,
     })
     out <- insight::text_remove_backticks(do.call(rbind, out), verbose = FALSE)
 
-  # .ci_generic does handle `vcov` correctly.
+    # .ci_generic does handle `vcov` correctly.
   } else {
     out <- .data_frame(.ci_generic(x,
-                                   ci = ci,
-                                   vcov = vcov,
-                                   vcov_args = vcov_args,
-                                   ...))
+      ci = ci,
+      vcov = vcov,
+      vcov_args = vcov_args,
+      ...
+    ))
 
     resp <- insight::get_parameters(x)$Response
     if (!"Reponse" %in% colnames(out) && nrow(out) == length(resp)) {
-      out[["Response"]] <- resp 
+      out[["Response"]] <- resp
     } else {
       if (!isTRUE(all(out$Response == resp))) {
-        stop(insight::format_message(
-            "Unable to assign labels to the model's parameters. Please report",
-            "this problem to the `parameters` Issue Tracker:",
-            "https://github.com/easystats/parameters/issues"
-        ), call. = FALSE)
+        insight::format_error(
+          "Unable to assign labels to the model's parameters.",
+          "Please report this problem to the {.pkg parameters} issue tracker:",
+          "{.url https://github.com/easystats/parameters/issues}"
+        )
       }
     }
   }
@@ -179,7 +180,7 @@ ci.mlm <- function(x,
 #' @export
 simulate_model.mlm <- function(model, iterations = 1000, ...) {
   responses <- insight::find_response(model, combine = FALSE)
-  out <- .simulate_model(model, iterations, component = "conditional", effects = "fixed")
+  out <- .simulate_model(model, iterations, component = "conditional", effects = "fixed", ...)
 
   cn <- paste0(colnames(out), rep(responses, each = length(colnames(out)) / length(responses)))
   colnames(out) <- cn
@@ -194,7 +195,7 @@ simulate_model.mlm <- function(model, iterations = 1000, ...) {
 simulate_parameters.mlm <- function(model,
                                     iterations = 1000,
                                     centrality = "median",
-                                    ci = .95,
+                                    ci = 0.95,
                                     ci_method = "quantile",
                                     test = "p-value",
                                     ...) {
