@@ -13,9 +13,9 @@
 #'   `group_level = FALSE` (the default), only information on SD and COR
 #'   are shown.
 #' @param component Which type of parameters to return, such as parameters for the
-#'   conditional model, the zero-inflated part of the model, the dispersion
+#'   conditional model, the zero-inflation part of the model, the dispersion
 #'   term, or other auxiliary parameters be returned? Applies to models with
-#'   zero-inflated and/or dispersion formula, or if parameters such as `sigma`
+#'   zero-inflation and/or dispersion formula, or if parameters such as `sigma`
 #'   should be included. May be abbreviated. Note that the *conditional*
 #'   component is also called *count* or *mean* component, depending on the
 #'   model. There are three convenient shortcuts: `component = "all"` returns
@@ -62,9 +62,9 @@
 model_parameters.stanreg <- function(model,
                                      centrality = "median",
                                      dispersion = FALSE,
-                                     ci = .95,
+                                     ci = 0.95,
                                      ci_method = "eti",
-                                     test = c("pd", "rope"),
+                                     test = "pd",
                                      rope_range = "default",
                                      rope_ci = 0.95,
                                      bf_prior = NULL,
@@ -76,7 +76,6 @@ model_parameters.stanreg <- function(model,
                                      group_level = FALSE,
                                      keep = NULL,
                                      drop = NULL,
-                                     parameters = keep,
                                      verbose = TRUE,
                                      ...) {
   # Processing
@@ -101,8 +100,12 @@ model_parameters.stanreg <- function(model,
   )
 
   if (effects != "fixed") {
-    random_effect_levels <- which(params$Effects %in% "random" & grepl("^(?!Sigma\\[)(.*)", params$Parameter, perl = TRUE))
-    if (length(random_effect_levels) && isFALSE(group_level)) params <- params[-random_effect_levels, ]
+    random_effect_levels <- which(
+      params$Effects %in% "random" & grepl("^(?!Sigma\\[)(.*)", params$Parameter, perl = TRUE)
+    )
+    if (length(random_effect_levels) && isFALSE(group_level)) {
+      params <- params[-random_effect_levels, , drop = FALSE]
+    }
   }
 
   params <- .add_pretty_names(params, model)
@@ -132,7 +135,7 @@ model_parameters.stanreg <- function(model,
 model_parameters.stanmvreg <- function(model,
                                        centrality = "median",
                                        dispersion = FALSE,
-                                       ci = .95,
+                                       ci = 0.95,
                                        ci_method = "eti",
                                        test = "pd",
                                        rope_range = "default",
@@ -144,7 +147,6 @@ model_parameters.stanmvreg <- function(model,
                                        standardize = NULL,
                                        keep = NULL,
                                        drop = NULL,
-                                       parameters = keep,
                                        verbose = TRUE,
                                        ...) {
   # Processing
