@@ -1,7 +1,7 @@
 #' @rdname model_parameters.averaging
 #' @export
 model_parameters.systemfit <- function(model,
-                                       ci = .95,
+                                       ci = 0.95,
                                        ci_method = NULL,
                                        bootstrap = FALSE,
                                        iterations = 1000,
@@ -87,7 +87,7 @@ degrees_of_freedom.systemfit <- function(model, ...) {
   f <- insight::find_formula(model)
   system_names <- names(f)
 
-  for (i in 1:length(system_names)) {
+  for (i in seq_along(system_names)) {
     dfs <- rep(s[[i]]$df[2], length(params[[i]]))
     df_names <- rep(names(params[i]), length(params[[i]]))
     df <- c(df, stats::setNames(dfs, df_names))
