@@ -335,7 +335,9 @@ n_factors <- function(x,
   )
 
   attr(out, "summary") <- by_factors
-  attr(out, "n") <- min(as.numeric(as.character(by_factors[by_factors$n_Methods == max(by_factors$n_Methods), c("n_Factors")])))
+  attr(out, "n") <- min(as.numeric(as.character(
+    by_factors[by_factors$n_Methods == max(by_factors$n_Methods), c("n_Factors")]
+  )))
 
   class(out) <- c("n_factors", "see_n_factors", class(out))
   out
@@ -545,8 +547,12 @@ print.n_clusters <- print.n_factors
 
 
   # Replace with own correlation matrix
-  junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_glasso <- EGAnet::EGA(cor, n = nobs, model = "glasso", plot.EGA = FALSE)$n.dim)))
-  junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_TMFG <- EGAnet::EGA(cor, n = nobs, model = "TMFG", plot.EGA = FALSE)$n.dim)))
+  junk <- utils::capture.output(suppressWarnings(suppressMessages(
+    nfac_glasso <- EGAnet::EGA(cor, n = nobs, model = "glasso", plot.EGA = FALSE)$n.dim
+  )))
+  junk <- utils::capture.output(suppressWarnings(suppressMessages(
+    nfac_TMFG <- EGAnet::EGA(cor, n = nobs, model = "TMFG", plot.EGA = FALSE)$n.dim
+  )))
 
   data.frame(
     n_Factors = as.numeric(c(nfac_glasso, nfac_TMFG)),
@@ -754,8 +760,11 @@ print.n_clusters <- print.n_factors
 
   data.frame(
     n_Factors = as.numeric(c(rez_rnd, rez_bokenstick, rez_ag)),
-    Method = c("Random (lambda)", "Random (F)", "Broken-Stick", "Auer-Gervini (twice)", "Auer-Gervini (spectral)", "Auer-Gervini (kmeans-2)", "AuerGervini (kmeans-3)", "Auer-Gervini (T)", "AuerGervini (CPT)"),
-    Family = "PCDimension"
+    Method = c("Random (lambda)", "Random (F)", "Broken-Stick", "Auer-Gervini (twice)",
+               "Auer-Gervini (spectral)", "Auer-Gervini (kmeans-2)", "AuerGervini (kmeans-3)",
+               "Auer-Gervini (T)", "AuerGervini (CPT)"),
+    Family = "PCDimension",
+    stringsAsFactors = FALSE
   )
 }
 
@@ -774,11 +783,13 @@ print.n_clusters <- print.n_factors
 
   lambda <- nFactors::eigenComputes(x, cor = cor, model = model, ...)
   if (length(which(lambda < 0)) > 0) {
-    stop("These indices are only valid with a principal component solution. So, only positive eigenvalues are permitted.")
+    insight::format_error(
+      "These indices are only valid with a principal component solution. So, only positive eigenvalues are permitted."
+    )
   }
 
   minPar <- c(min(lambda) - abs(min(lambda)) + .001, 0.001)
-  maxPar <- c(max(lambda), stats::lm(lambda ~ I(length(lambda):1))$coef[2])
+  maxPar <- c(max(lambda), stats::lm(lambda ~ I(rev(seq_along(lambda))))$coef[2])
 
 
   n <- N
