@@ -3,8 +3,13 @@ print.compare_parameters <- function(x,
                                      digits = 2,
                                      ci_digits = 2,
                                      p_digits = 3,
+                                     caption = NULL,
+                                     subtitle = NULL,
+                                     footer = NULL,
                                      style = NULL,
                                      groups = NULL,
+                                     split_components = TRUE,
+                                     column_width = NULL,
                                      ...) {
   # save original input
   orig_x <- x
@@ -28,17 +33,31 @@ print.compare_parameters <- function(x,
   formatted_table <- format(
     x,
     style,
-    split_components = TRUE,
+    split_components = split_components,
     digits = digits,
     ci_digits = ci_digits,
     p_digits = p_digits,
     ci_width = "auto",
     ci_brackets = c("(", ")"),
     format = "text",
-    groups = groups,
+    groups = groups
   )
 
-  cat(insight::export_table(formatted_table, format = "text", footer = NULL, empty_line = "-"))
+  # if we have multiple components, we can align colum width across components here
+  if (!is.null(column_width) && all(column_width == "fixed") && is.list(formatted_table)) {
+    column_width <- .find_min_colwidth(formatted_table)
+  }
+
+  cat(insight::export_table(
+    formatted_table,
+    format = "text",
+    caption = caption,
+    subtitle = subtitle,
+    footer = footer,
+    empty_line = "-",
+    width = column_width,
+    ...
+  ))
 
   invisible(orig_x)
 }
