@@ -6,8 +6,8 @@
 #'
 #' @param model A mixed effects model (including `stanreg` models).
 #' @param component Should all parameters, parameters for the conditional model,
-#'   for the zero-inflated part of the model, or the dispersion model be returned?
-#'   Applies to models with zero-inflated and/or dispersion component. `component`
+#'   for the zero-inflation part of the model, or the dispersion model be returned?
+#'   Applies to models with zero-inflation and/or dispersion component. `component`
 #'   may be one of `"conditional"`, `"zi"`, `"zero-inflated"`, `"dispersion"` or
 #'    `"all"` (default). May be abbreviated.
 #'
@@ -15,35 +15,40 @@
 #'   including number of levels per random effect group, as well as complete
 #'   observations in the model.
 #'
-#' @details The variance components are obtained from
-#'   [insight::get_variance()] and are denoted as following:
-#'   \subsection{Within-group (or residual) variance}{
-#'     The residual variance, \ifelse{html}{\out{&sigma;<sup>2</sup><sub>&epsilon;</sub>}}{\eqn{\sigma^2_\epsilon}},
-#'     is the sum of the distribution-specific variance and the variance due to additive dispersion.
-#'     It indicates the *within-group variance*.
-#'   }
-#'   \subsection{Between-group random intercept variance}{
-#'     The random intercept variance, or *between-group* variance
-#'     for the intercept (\ifelse{html}{\out{&tau;<sub>00</sub>}}{\eqn{\tau_{00}}}),
-#'     is obtained from `VarCorr()`. It indicates how much groups
-#'     or subjects differ from each other.
-#'   }
-#'   \subsection{Between-group random slope variance}{
-#'     The random slope variance, or *between-group* variance
-#'     for the slopes (\ifelse{html}{\out{&tau;<sub>11</sub>}}{\eqn{\tau_{11}}})
-#'     is obtained from `VarCorr()`. This measure is only available
-#'     for mixed models with random slopes. It indicates how much groups
-#'     or subjects differ from each other according to their slopes.
-#'   }
-#'   \subsection{Random slope-intercept correlation}{
-#'     The random slope-intercept correlation
-#'     (\ifelse{html}{\out{&rho;<sub>01</sub>}}{\eqn{\rho_{01}}})
-#'     is obtained from `VarCorr()`. This measure is only available
-#'     for mixed models with random intercepts and slopes.
-#'   }
-#'   **Note:** For the within-group and between-group variance, variance
-#'   and standard deviations (which are simply the square root of the variance)
-#'   are shown.
+#' @details The variance components are obtained from [insight::get_variance()]
+#' and are denoted as following:
+#'
+#' **Within-group (or residual) variance**
+#'
+#' The residual variance, \ifelse{html}{\out{&sigma;<sup>2</sup><sub>&epsilon;</sub>}}{\eqn{\sigma^2_\epsilon}},
+#' is the sum of the distribution-specific variance and the variance due to additive dispersion.
+#' It indicates the *within-group variance*.
+#'
+#' **Between-group random intercept variance**
+#'
+#' The random intercept variance, or *between-group* variance
+#' for the intercept (\ifelse{html}{\out{&tau;<sub>00</sub>}}{\eqn{\tau_{00}}}),
+#' is obtained from `VarCorr()`. It indicates how much groups
+#' or subjects differ from each other.
+#'
+#' **Between-group random slope variance**
+#'
+#' The random slope variance, or *between-group* variance
+#' for the slopes (\ifelse{html}{\out{&tau;<sub>11</sub>}}{\eqn{\tau_{11}}})
+#' is obtained from `VarCorr()`. This measure is only available
+#' for mixed models with random slopes. It indicates how much groups
+#' or subjects differ from each other according to their slopes.
+#'
+#' **Random slope-intercept correlation**
+#'
+#' The random slope-intercept correlation
+#' (\ifelse{html}{\out{&rho;<sub>01</sub>}}{\eqn{\rho_{01}}})
+#' is obtained from `VarCorr()`. This measure is only available
+#' for mixed models with random intercepts and slopes.
+#'
+#' **Note:** For the within-group and between-group variance, variance
+#' and standard deviations (which are simply the square root of the variance)
+#' are shown.
 #'
 #' @examples
 #' if (require("lme4")) {
@@ -64,7 +69,10 @@ random_parameters <- function(model, component = "conditional") {
 # helper -----------------------------------
 
 .n_randomeffects <- function(model) {
-  sapply(insight::get_data(model, verbose = FALSE)[insight::find_random(model, split_nested = TRUE, flatten = TRUE)], function(i) insight::n_unique(i))
+  sapply(
+    insight::get_data(model, verbose = FALSE)[insight::find_random(model, split_nested = TRUE, flatten = TRUE)],
+    function(i) insight::n_unique(i)
+  )
 }
 
 
