@@ -4,14 +4,13 @@
 #'
 #'
 #' @examples
-#' library(parameters)
-#' library(psych)
+#' if (require("psych")) {
+#'   pca <- model_parameters(psych::fa(attitude, nfactors = 3))
+#'   loadings <- reshape_loadings(pca)
 #'
-#' pca <- model_parameters(psych::fa(attitude, nfactors = 3))
-#' loadings <- reshape_loadings(pca)
-#'
-#' loadings
-#' reshape_loadings(loadings)
+#'   loadings
+#'   reshape_loadings(loadings)
+#' }
 #' @export
 reshape_loadings <- function(x, ...) {
   UseMethod("reshape_loadings")
@@ -35,7 +34,7 @@ reshape_loadings.parameters_efa <- function(x, threshold = NULL, ...) {
 #' @param loadings_columns Vector indicating the columns corresponding to loadings.
 #' @export
 reshape_loadings.data.frame <- function(x, threshold = NULL, loadings_columns = NULL, ...) {
-  if (is.null(loadings_columns)) loadings_columns <- 1:ncol(x)
+  if (is.null(loadings_columns)) loadings_columns <- seq_len(ncol(x))
   if (length(loadings_columns) > 1) {
     .long_loadings(x, threshold = threshold, loadings_columns = loadings_columns)
   }
@@ -43,8 +42,6 @@ reshape_loadings.data.frame <- function(x, threshold = NULL, loadings_columns =
 
 
 
-#' @importFrom insight export_table format_table
-#' @importFrom stats reshape
 #' @keywords internal
 .wide_loadings <- function(loadings,
                            loadings_columns = "Loading",
@@ -79,7 +76,6 @@ reshape_loadings.data.frame <- function(x, threshold = NULL, loadings_columns =
 }
 
 
-#' @importFrom stats reshape
 #' @keywords internal
 .long_loadings <- function(loadings, threshold = NULL, loadings_columns = NULL) {
   if (is.null(loadings_columns)) {
@@ -101,7 +97,7 @@ reshape_loadings.data.frame <- function(x, threshold = NULL, loadings_columns =
   )
 
   # Restore component names
-  for (i in 1:.n_unique(long$Component)) {
+  for (i in 1:insight::n_unique(long$Component)) {
     component <- unique(long$Component)[[i]]
     name <- names(loadings)[loadings_columns][[i]]
     long[long$Component == component, "Component"] <- name
@@ -128,7 +124,6 @@ reshape_loadings.data.frame <- function(x, threshold = NULL, loadings_columns =
 
 
 
-#' @importFrom insight export_table
 #' @export
 print.parameters_loadings <- function(x, ...) {
   formatted_table <- insight::format_table(x)
