@@ -1,32 +1,38 @@
-#' Simulate Model Parameters
+#' @title Simulate Model Parameters
+#' @name simulate_parameters
 #'
-#' Compute simulated draws of parameters and their related indices such as Confidence Intervals (CI) and p-values. Simulating parameter draws can be seen as a (computationally faster) alternative to bootstrapping.
+#' @description Compute simulated draws of parameters and their related indices
+#' such as Confidence Intervals (CI) and p-values. Simulating parameter draws
+#' can be seen as a (computationally faster) alternative to bootstrapping.
 #'
 #' @inheritParams simulate_model
 #' @inheritParams bayestestR::describe_posterior
 #'
 #' @return A data frame with simulated parameters.
 #'
-#' @references Gelman A, Hill J. Data analysis using regression and multilevel/hierarchical models. Cambridge; New York: Cambridge University Press 2007: 140-143
+#' @references Gelman A, Hill J. Data analysis using regression and
+#' multilevel/hierarchical models. Cambridge; New York: Cambridge University
+#' Press 2007: 140-143
 #'
-#' @seealso [bootstrap_model()], [bootstrap_parameters()], [simulate_model()]
+#' @seealso [`bootstrap_model()`], [`bootstrap_parameters()`], [`simulate_model()`]
 #'
 #' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html) implemented in the [**see**-package](https://easystats.github.io/see/).
 #'
 #' @details
-#'   \subsection{Technical Details}{
-#'     `simulate_parameters()` is a computationally faster alternative
-#'     to `bootstrap_parameters()`. Simulated draws for coefficients are based
-#'     on a multivariate normal distribution (`MASS::mvrnorm()`) with mean
-#'     `mu = coef(model)` and variance `Sigma = vcov(model)`.
-#'   }
-#'   \subsection{Models with Zero-Inflation Component}{
-#'     For models from packages **glmmTMB**, **pscl**, **GLMMadaptive** and
-#'     **countreg**, the `component` argument can be used to specify
-#'     which parameters should be simulated. For all other models, parameters
-#'     from the conditional component (fixed effects) are simulated. This may
-#'     include smooth terms, but not random effects.
-#'   }
+#' **Technical Details**
+#'
+#' `simulate_parameters()` is a computationally faster alternative
+#' to `bootstrap_parameters()`. Simulated draws for coefficients are based
+#' on a multivariate normal distribution (`MASS::mvrnorm()`) with mean
+#' `mu = coef(model)` and variance `Sigma = vcov(model)`.
+#'
+#' **Models with Zero-Inflation Component**
+#'
+#' For models from packages **glmmTMB**, **pscl**, **GLMMadaptive** and
+#' **countreg**, the `component` argument can be used to specify
+#' which parameters should be simulated. For all other models, parameters
+#' from the conditional component (fixed effects) are simulated. This may
+#' include smooth terms, but not random effects.
 #'
 #' @examples
 #' model <- lm(Sepal.Length ~ Species * Petal.Width + Petal.Length, data = iris)
@@ -57,10 +63,13 @@ simulate_parameters <- function(model, ...) {
 simulate_parameters.default <- function(model,
                                         iterations = 1000,
                                         centrality = "median",
-                                        ci = .95,
+                                        ci = 0.95,
                                         ci_method = "quantile",
                                         test = "p-value",
                                         ...) {
+  # check for valid input
+  .is_model_valid(model)
+
   data <- simulate_model(model, iterations = iterations, ...)
   out <- .summary_bootstrap(
     data = data,
@@ -82,6 +91,7 @@ simulate_parameters.default <- function(model,
   attr(out, "ci") <- ci
   attr(out, "ci_method") <- ci_method
   attr(out, "centrality") <- centrality
+  attr(out, "simulated") <- TRUE
 
   out
 }
