@@ -1,4 +1,4 @@
-if (require("testthat") && require("parameters") && require("betareg")) {
+if (requiet("testthat") && requiet("parameters") && requiet("betareg")) {
   data("GasolineYield")
   data("FoodExpenditure")
 
@@ -46,6 +46,13 @@ if (require("testthat") && require("parameters") && require("betareg")) {
     )
   })
 
+  # check vcov args
+  test_that("model_parameters", {
+    expect_warning(out <- model_parameters(m1, vcov = "vcovHAC"))
+    expect_equal(out$SE, unname(coef(summary(m1))[[1]][, 2]), tolerance = 1e-3)
+  })
+
+
   test_that("model_parameters", {
     expect_equal(
       model_parameters(m1)$Coefficient,
