@@ -1,7 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllparametersTests") == "yes"
 
 if (.runThisTest &&
-  getRversion() >= "3.6.0" &&
   requiet("testthat") &&
   requiet("parameters") &&
   requiet("glmmTMB")) {
@@ -445,7 +444,7 @@ if (.runThisTest &&
       expect_equal(
         out[-6],
         c(
-          "# Fixed Effects (Zero-Inflated Model)",
+          "# Fixed Effects (Zero-Inflation Component)",
           "",
           "Parameter   | Log-Mean |   SE |        95% CI |     z |     p",
           "-------------------------------------------------------------",
@@ -459,7 +458,7 @@ if (.runThisTest &&
       expect_equal(
         out,
         c(
-          "# Random Effects (Zero-Inflated Model)",
+          "# Random Effects (Zero-Inflation Component)",
           "",
           "Parameter                   | Coefficient |        95% CI",
           "---------------------------------------------------------",
@@ -496,14 +495,14 @@ if (.runThisTest &&
       expect_equal(
         out[-6],
         c(
-          "# Fixed Effects (Zero-Inflated Model)",
+          "# Fixed Effects (Zero-Inflation Component)",
           "",
           "Parameter   | Log-Mean |   SE |        95% CI |     z |     p",
           "-------------------------------------------------------------",
           "(Intercept) |     1.89 | 0.66 | [ 0.59, 3.19] |  2.84 | 0.004",
           "camper [1]  |    -0.17 | 0.39 | [-0.93, 0.59] | -0.44 | 0.663",
           "",
-          "# Random Effects (Zero-Inflated Model)",
+          "# Random Effects (Zero-Inflation Component)",
           "",
           "Parameter                   | Coefficient |        95% CI",
           "---------------------------------------------------------",
@@ -525,7 +524,7 @@ if (.runThisTest &&
           "child       |    -1.09 | 0.10 | [-1.28, -0.90] | -11.09 | < .001",
           "camper [1]  |     0.27 | 0.10 | [ 0.07,  0.47] |   2.70 | 0.007 ",
           "",
-          "# Fixed Effects (Zero-Inflated Model)",
+          "# Fixed Effects (Zero-Inflation Component)",
           "",
           "Parameter   | Log-Odds |   SE |        95% CI |     z |     p",
           "-------------------------------------------------------------",
@@ -540,7 +539,7 @@ if (.runThisTest &&
           "SD (xb: persons)            |        1.21 | [ 0.60, 2.44]",
           "Cor (Intercept~xb: persons) |       -1.00 | [-1.00, 1.00]",
           "",
-          "# Random Effects (Zero-Inflated Model)", "", "Parameter                   | Coefficient |        95% CI",
+          "# Random Effects (Zero-Inflation Component)", "", "Parameter                   | Coefficient |        95% CI",
           "---------------------------------------------------------",
           "SD (Intercept: persons)     |        2.74 | [ 1.16, 6.43]",
           "SD (zg: persons)            |        1.57 | [ 0.64, 3.82]",
@@ -565,7 +564,7 @@ if (.runThisTest &&
           "child       |  -1.0875 | 0.0981 | [-1.27966, -0.89529] | -11.0903 | < .001",
           "camper [1]  |   0.2723 | 0.1009 | [ 0.07460,  0.46999] |   2.6996 | 0.007 ",
           "",
-          "# Fixed Effects (Zero-Inflated Model)",
+          "# Fixed Effects (Zero-Inflation Component)",
           "",
           "Parameter   | Log-Odds |     SE |              95% CI |       z |     p",
           "-----------------------------------------------------------------------",
@@ -580,7 +579,7 @@ if (.runThisTest &&
           "SD (xb: persons)            |      1.2132 | [ 0.60210, 2.44440]",
           "Cor (Intercept~xb: persons) |     -1.0000 | [-1.00000, 1.00000]",
           "",
-          "# Random Effects (Zero-Inflated Model)",
+          "# Random Effects (Zero-Inflation Component)",
           "",
           "Parameter                   | Coefficient |              95% CI",
           "---------------------------------------------------------------",
@@ -602,7 +601,7 @@ if (.runThisTest &&
           "child       |  -1.0875 | 0.0981 | [-1.27966, -0.89529] | -11.0903 | < .001",
           "camper [1]  |   0.2723 | 0.1009 | [ 0.07460,  0.46999] |   2.6996 | 0.007 ",
           "",
-          "# Fixed Effects (Zero-Inflated Model)",
+          "# Fixed Effects (Zero-Inflation Component)",
           "",
           "Parameter   | Log-Odds |     SE |              95% CI |       z |     p",
           "-----------------------------------------------------------------------",
@@ -617,7 +616,7 @@ if (.runThisTest &&
           "SD (xb: persons)            |      1.2132 | [ 0.60210, 2.44440]",
           "Cor (Intercept~xb: persons) |     -1.0000 | [-1.00000, 1.00000]",
           "",
-          "# Random Effects (Zero-Inflated Model)", "", "Parameter                   | Coefficient |              95% CI",
+          "# Random Effects (Zero-Inflation Component)", "", "Parameter                   | Coefficient |              95% CI",
           "---------------------------------------------------------------",
           "SD (Intercept: persons)     |      2.7358 | [ 1.16473, 6.42622]",
           "SD (zg: persons)            |      1.5683 | [ 0.64351, 3.82225]",
@@ -683,7 +682,7 @@ if (.runThisTest &&
             "Side [Left]        |    -0.04 | 0.20 | [-0.44, 0.37] | -0.17 | 0.862 ",
             "Jaw [Maxillar]     |    -0.10 | 0.21 | [-0.51, 0.30] | -0.51 | 0.612 ",
             "",
-            "# Zero-Inflated",
+            "# Zero-Inflation",
             "",
             "Parameter          | Log-Odds |   SE |         95% CI |     z |      p",
             "----------------------------------------------------------------------",
@@ -756,7 +755,7 @@ if (.runThisTest &&
         "child       |    -1.14 | 0.09 | [-1.32, -0.96] | -12.27 | < .001",
         "camper [1]  |     0.73 | 0.09 | [ 0.55,  0.92] |   7.85 | < .001",
         "",
-        "# Zero-Inflated",
+        "# Zero-Inflation",
         "",
         "Parameter   | Log-Odds |   SE |         95% CI |     z |      p",
         "---------------------------------------------------------------",
@@ -778,7 +777,7 @@ if (.runThisTest &&
         "child       | 0.32 | 0.03 | [0.27, 0.38] | -12.27 | < .001",
         "camper [1]  | 2.08 | 0.19 | [1.73, 2.50] |   7.85 | < .001",
         "",
-        "# Zero-Inflated",
+        "# Zero-Inflation",
         "",
         "Parameter   | Odds Ratio |   SE |        95% CI |     z |      p",
         "----------------------------------------------------------------",
@@ -800,7 +799,7 @@ if (.runThisTest &&
         "child       |    -1.14 | 0.09 | [-1.32, -0.96] | -12.27 | < .001",
         "camper [1]  |     0.73 | 0.09 | [ 0.55,  0.92] |   7.85 | < .001",
         "",
-        "# Fixed Effects (Zero-Inflated Model)",
+        "# Fixed Effects (Zero-Inflation Component)",
         "",
         "Parameter   | Log-Odds |   SE |         95% CI |     z |      p",
         "---------------------------------------------------------------",
@@ -814,7 +813,7 @@ if (.runThisTest &&
         "----------------------------------------------------",
         "SD (Intercept: persons) |        0.93 | [0.46, 1.89]",
         "",
-        "# Random Effects (Zero-Inflated Model)",
+        "# Random Effects (Zero-Inflation Component)",
         "",
         "Parameter               | Coefficient |       95% CI",
         "----------------------------------------------------",
